# Copyright (c) 2005-2006, Samuel Schluep, ETH Zurich and Infrae
# All rights reserved. See also LICENSE.txt

# Silva
from Products.Silva.ExtensionRegistry import extensionRegistry
from Products.Silva.fssite import registerDirectory
from Products.Silva.ImporterRegistry import importer_registry
from Products.SilvaMetadata.Compatibility import registerTypeForMetadata
from Products.SilvaMetadata.Access import registerAccessHandler, invokeAccessHandler
# Silva Document
from Products.SilvaDocument import mixedcontentsupport
from Products.SilvaDocument.EditorSupportNested import mixedContentSupportRegistry
# Silva Glossary
import install
import GlossaryService
import GlossaryEntry
import Glossary
import glossarycontentsupport


def initialize(context):
    # register Silva Glossary content types for Silva
    extensionRegistry.register(
        'SilvaGlossary', 'Silva Glossary', context, [GlossaryEntry, Glossary],
        install, depends_on='SilvaDocument')

    # register service classes for Zope (Widget Registry Extension)
    context.registerClass(
        GlossaryService.GlossaryService,
        constructors = (GlossaryService.manage_addGlossaryServiceForm,
                        GlossaryService.manage_addGlossaryService),
                        icon = "www/glossary_service.png"
        )

    # register the FileSystemSite directories
    registerDirectory('views', globals())
    registerDirectory('widgets', globals())
    registerDirectory('globals_silva_glossary', globals())

    # Register default paragraph support for glossary entry description.
    mixedContentSupportRegistry.registerMetaTypeDefault(
        'Silva Glossary Entry', mixedcontentsupport.ParagraphSupport)
    # Register the GlossaryParagraphSupport for Silva Document, overwrites the
    # default to include glossary link rendering.
    mixedContentSupportRegistry.registerDefault(
        glossarycontentsupport.GlossaryParagraphSupport)

    # register xml import functions
    # we let the xml import functionality of Publication handle any root elements, since a Silva instance can not import another root
    importer_registry.register_tag('silva_glossaryentry', GlossaryEntry.xml_import_handler)
    #importer_registry.register_tag('silva_glossary', Glossary.xml_import_handler)

    # initialize the metadata system
    # register Silva Glossary types for the metadata system
    registerTypeForMetadata(GlossaryEntry.GlossaryEntry.meta_type)
    registerTypeForMetadata(Glossary.Glossary.meta_type)

def __allow_access_to_unprotected_subobjects__(name, value=None):
    return name in ('helpers')

